@@ -557,6 +557,66 @@ class SyncAPIClient(BaseClient):
             ResponseT, self.request(cast_to, opts, stream=stream, stream_cls=stream_cls)
         )
 
+    def get(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            params: list[tuple[str, str]] | None = None,
+            options: ExtraRequestOptions = {},
+            stream: bool = False,
+            stream_cls: type[_StreamT] | None = None,
+    ) -> ResponseT | _StreamT:
+        opts = RequestOptions.construct(
+            method="get",
+            url=path,
+            params=params,
+            **options,
+        )
+
+        return cast(
+            ResponseT, self.request(cast_to, opts, stream=stream, stream_cls=stream_cls)
+        )
+
+    def delete(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            params: list[tuple[str, str]] | None = None,
+            options: ExtraRequestOptions = {},
+    ) -> ResponseT:
+        opts = RequestOptions.construct(  # type: ignore
+            method="delete",
+            url=path,
+            params=params,
+            **options,
+        )
+
+        return cast(ResponseT, self.request(cast_to, opts))
+
+    def post_without_retry(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            body: Dict | None = None,
+            options: ExtraRequestOptions = {},
+            files: RequestFiles | None = None,
+            stream: bool = False,
+            stream_cls: type[_StreamT] | None = None,
+    ) -> ResponseT | _StreamT:
+        opts = RequestOptions.construct(  # type: ignore
+            method="post",
+            url=path,
+            body=body,
+            **options,
+        )
+
+        return cast(
+            ResponseT, self.request(cast_to, opts, remaining_retries=0, stream=stream, stream_cls=stream_cls)
+        )
+
     def request(
             self,
             cast_to: Type[ResponseT],
@@ -681,6 +741,62 @@ class AsyncAPIClient(BaseClient):
 
         return await self.request(cast_to, opts, stream=stream, stream_cls=stream_cls)
 
+    async def get(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            params: list[tuple[str, str]] | None = None,
+            options: ExtraRequestOptions = {},
+            stream: bool = False,
+            stream_cls: type[_AsyncStreamT] | None = None,
+    ) -> ResponseT | _AsyncStreamT:
+        opts = RequestOptions.construct(
+            method="get",
+            url=path,
+            params=params,
+            **options,
+        )
+
+        return await self.request(cast_to, opts, stream=stream, stream_cls=stream_cls)
+
+    async def delete(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            params: list[tuple[str, str]] | None = None,
+            options: ExtraRequestOptions = {},
+    ) -> ResponseT:
+        opts = RequestOptions.construct(
+            method="delete",
+            url=path,
+            params=params,
+            **options,
+        )
+
+        return await self.request(cast_to, opts)
+
+    async def post_without_retry(
+            self,
+            path: str,
+            *,
+            cast_to: Type[ResponseT],
+            body: Dict | None = None,
+            options: ExtraRequestOptions = {},
+            files: RequestFiles | None = None,
+            stream: bool = False,
+            stream_cls: type[_AsyncStreamT] | None = None,
+    ) -> ResponseT | _AsyncStreamT:
+        opts = RequestOptions.construct(
+            method="post",
+            url=path,
+            body=body,
+            **options,
+        )
+
+        return await self.request(cast_to, opts, remaining_retries=0, stream=stream, stream_cls=stream_cls)
+
     async def request(
             self,
             cast_to: Type[ResponseT],
